pub trait LoopGuardTripLog: Send + Sync {
// Required method
fn summary<'life0, 'async_trait>(
&'life0 self,
first_day: i64,
) -> Pin<Box<dyn Future<Output = Result<Vec<LoopGuardTripDay>, RepositoryError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Reads the loop guard’s log back.
Required Methods
Sourcefn summary<'life0, 'async_trait>(
&'life0 self,
first_day: i64,
) -> Pin<Box<dyn Future<Output = Result<Vec<LoopGuardTripDay>, RepositoryError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn summary<'life0, 'async_trait>(
&'life0 self,
first_day: i64,
) -> Pin<Box<dyn Future<Output = Result<Vec<LoopGuardTripDay>, RepositoryError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Every day from first_day on (an epoch_day) that either table
holds a row for, one entry per model, gglib version and mode, newest
day first. A day with scans and no trips is included, with trips at
zero; so is a trip whose scan was lost, with scanned at zero.